summaryrefslogtreecommitdiffstats
path: root/libksieve/parser
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
commit9cc13dcbb01a96c9e60a07ca63c61d24b374f50d (patch)
treeab537a329b9613e11dce8195761f93ffe82aed24 /libksieve/parser
parent3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (diff)
downloadtdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.tar.gz
tdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.
Diffstat (limited to 'libksieve/parser')
-rw-r--r--libksieve/parser/lexer.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libksieve/parser/lexer.cpp b/libksieve/parser/lexer.cpp
index 3bc75c96..a38c6102 100644
--- a/libksieve/parser/lexer.cpp
+++ b/libksieve/parser/lexer.cpp
@@ -40,7 +40,7 @@
#include <tqstring.h>
#include <tqstringlist.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
#include <memory> // std::auto_ptr
@@ -476,9 +476,9 @@ namespace KSieve {
const int identifierLength = mState.cursor - identifierStart;
// Can use the fast fromLatin1 here, since identifiers are always
// in the us-ascii subset:
- result += TQString::fromLatin1( identifierStart, identifierLength );
+ result += TQString::tqfromLatin1( identifierStart, identifierLength );
if ( atEnd() || isDelim( *mState.cursor ) )
return true;
@@ -476,9 +476,9 @@ namespace KSieve {
const int identifierLength = mState.cursor - identifierStart;
- // Can use the fast fromLatin1 here, since identifiers are always
+ // Can use the fast tqfromLatin1 here, since identifiers are always
// in the us-ascii subset: